"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LimitStream = void 0;
const stream_1 = require("stream");
class LimitStream extends stream_1.Transform {
    constructor(limit) {
        super();
        this.bytes = 0;
        this.limit = limit;
    }
    _transform(chunk, encoding, callback) {
        var length = !Buffer.isBuffer(chunk) ? Buffer.byteLength(chunk, encoding) : chunk.length;
        this.bytes += length;
        if (this.bytes > this.limit) {
            var err = new Error('maximum file length exceeded');
            err.code = 'ETOOBIG';
            callback(err);
        }
        else {
            this.push(chunk);
            this.emit('progress', this.bytes, length);
            callback();
        }
    }
}
exports.LimitStream = LimitStream;
//# sourceMappingURL=limit-stream.js.map